Usage — django-vue-utilities 0.1 documentation

# Usage

Load the template tag in a template. Run the tag with an opening and closing tag.

    {% extends "base.html" %}

    {% load vue_utils %}

    {% block extra_js %}
      {# Import entrypoint JavaScript, choosing dev or static source depending on settings #}
      <script type="module" crossorigin src="{% vue_bundle_url 'my_vue_entrypoint' %}"></script>

      {# 'provide" strings which can 'injected' throughout the Vue app, including from within a pinia store #}
      {% url 'home' as homeUrl %}
      {% vue_provide 'homeUrl' homeUrl %}
    {% endblock %}